var NAVTREE =
[
  [ "WiredTiger", "index.html", [
    [ "Reference Guide", "index.html", "index" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Class List", "annotated.html", "annotated" ],
    [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
    [ "Class Members", "functions.html", [
      [ "All", "functions.html", "functions_dup" ],
      [ "Functions", "functions_func.html", "functions_func" ],
      [ "Variables", "functions_vars.html", null ],
      [ "Enumerator", "functions_eval.html", null ]
    ] ],
    [ "Examples", "examples.html", "examples" ],
    [ "Community", "community.html", null ],
    [ "License", "license.html", null ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classcom_1_1wiredtiger_1_1db_1_1_pack_input_stream.html",
"devdoc-schema.html#schema_create",
"group__wt.html#ga2c96ee16874c2beb1bb96979648f5b21",
"group__wt.html#ga8bacfcb1989b797fcc50f12ea7696ecc",
"group__wt.html#gafddb1885f74ab7abf0de9c9ae0630cb9",
"struct_w_t___e_n_c_r_y_p_t_o_r.html#abad5447ebeb99d06b9024df435cffc26",
"upgrading.html#version_260"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';